@@ -1,6 +1,6 @@
 var Ephy = {};
 
-Ephy.formControlsAssociated = function(pageID, forms, serializer, rememberPasswords)
+Ephy.formControlsAssociated = function(pageID, forms, serializer)
 {
     Ephy.formManagers = [];
 
@@ -9,8 +9,7 @@ Ephy.formControlsAssociated = function(pageID, forms, serializer, rememberPasswo
             continue;
         let formManager = new Ephy.FormManager(pageID, forms[i]);
         formManager.handleSensitiveElement(serializer);
-        if (rememberPasswords)
-            formManager.preFillForms();
+        formManager.preFillForms();
         Ephy.formManagers.push(formManager);
     }
 }
@@ -330,7 +329,9 @@ Ephy.PasswordManager = class PasswordManager
     {
         let element = this._takePendingPromise(id)
         if (element) {
-            if (username !== '' && password !== '')
+            if (username === '')
+                username = null;
+            if (password !== '')
                 element.resolver({username, password});
             else
                 element.resolver(null);
@@ -425,6 +426,9 @@ Ephy.FormManager = class FormManager
 
     preFillForms()
     {
+        if (!Ephy.shouldRememberPasswords())
+            return;
+
         this._formAuth = this._findFormAuthElements(true);
         if (!this._formAuth || !this._formAuth.passwordNode) {
             Ephy.log('No pre-fillable/hookable form found');
@@ -460,13 +464,16 @@ Ephy.FormManager = class FormManager
 
     preFill()
     {
+        if (!Ephy.shouldRememberPasswords())
+            return;
+
         const self = this;
         Ephy.passwordManager.query(
             this._formAuth.url.origin,
             this._formAuth.targetURL.origin,
             this._formAuth.usernameNode && this._formAuth.usernameNode.value ? this._formAuth.usernameNode.value : null,
-            this._formAuth.usernameNode ? this._formAuth.usernameNode.name : null,
-            this._formAuth.passwordNode.name ? this._formAuth.passwordNode.name : null).then(function (authInfo) {
+            this._formAuth.usernameNode ? (this._formAuth.usernameNode.name ? this._formAuth.usernameNode.name : this._formAuth.usernameNode.id) : null,
+            this._formAuth.passwordNode.name ? this._formAuth.passwordNode.name : this._formAuth.passwordNode.id).then(function (authInfo) {
                 if (!authInfo) {
                     Ephy.log('No result');
                     return;
@@ -491,6 +498,9 @@ Ephy.FormManager = class FormManager
 
     handleFormSubmission()
     {
+        if (!Ephy.shouldRememberPasswords())
+            return;
+
         if (!this._formAuth)
             return;
 
@@ -500,17 +510,17 @@ Ephy.FormManager = class FormManager
             return;
         }
 
-        if (!this._formAuth.passwordNode.value || !this._formAuth.passwordNode.name)
+        if (!this._formAuth.passwordNode.value || (!this._formAuth.passwordNode.name && !this._formAuth.passwordNode.id))
             return;
 
         let password = this._formAuth.passwordNode.value;
-        let passwordField = this._formAuth.passwordNode.name;
+        let passwordField = this._formAuth.passwordNode.name ? this._formAuth.passwordNode.name : this._formAuth.passwordNode.id;
 
         let username = null;
         let usernameField = null;
-        if (this._formAuth.usernameNode && this._formAuth.usernameNode.value && this._formAuth.usernameNode.name) {
+        if (this._formAuth.usernameNode && this._formAuth.usernameNode.value && (this._formAuth.usernameNode.name || this._formAuth.usernameNode.id)) {
             username = this._formAuth.usernameNode.value;
-            usernameField = this._formAuth.usernameNode.name;
+            usernameField = this._formAuth.usernameNode.name ? this._formAuth.usernameNode.name : this._formAuth.usernameNode.id;
         }
 
         this._formAuth.url = new URL(String(window.location));
@@ -583,9 +593,12 @@ Ephy.FormManager = class FormManager
 
     _sensitiveElementFocused(event)
     {
-        let url = new URL(this._form.action);
-        // Warning: we do not whitelist localhost because it could be redirected by DNS.
-        let isInsecureAction = url.protocol == 'http:' && url.hostname != "127.0.0.1" && url.hostname != "::1";
+        let isInsecureAction = false;
+        if (this._form.action) {
+            let url = new URL(this._form.action);
+            // Warning: we do not whitelist localhost because it could be redirected by DNS.
+            isInsecureAction = url.protocol == 'http:' && url.hostname != "127.0.0.1" && url.hostname != "::1";
+        }
         window.webkit.messageHandlers.sensitiveFormFocused.postMessage(this._sensitiveElementMessageSerializer(this._pageID, isInsecureAction));
     }
 
