@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
  * Copyright © 2017 Igalia S.L.
+ * Copyright © 2018 Jan-Michael Brummer
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,12 +27,16 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (EphySuggestion, ephy_suggestion, EPHY, SUGGESTION, DzlSuggestion)
 
-// FIXME: How about favicon?
-EphySuggestion *ephy_suggestion_new                  (const char *title,
+EphySuggestion *ephy_suggestion_new                  (const char *title_markup,
+                                                      const char *unescaped_title,
                                                       const char *uri);
-EphySuggestion *ephy_suggestion_new_without_subtitle (const char *title,
+EphySuggestion *ephy_suggestion_new_without_subtitle (const char *title_markup,
+                                                      const char *unescaped_title,
                                                       const char *uri);
 const char     *ephy_suggestion_get_unescaped_title  (EphySuggestion *self);
 const char     *ephy_suggestion_get_uri              (EphySuggestion *self);
 
+void            ephy_suggestion_set_favicon          (EphySuggestion  *self,
+                                                      cairo_surface_t *favicon);
+
 G_END_DECLS
