@@ -392,7 +392,30 @@ homepage_button_release_event_cb (GtkButton *button,
   switch (((GdkEventButton *)event)->button) {
     case GDK_BUTTON_MIDDLE:
       action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "homepage-new-tab");
-       g_action_activate (action, NULL);
+      g_action_activate (action, NULL);
+      break;
+    default:
+      break;
+  }
+
+  return G_SOURCE_REMOVE;
+}
+
+static gboolean
+new_tab_button_release_event_cb (GtkButton *button,
+                                 GdkEvent  *event,
+                                 gpointer   user_data)
+{
+  EphyActionBarStart *action_bar_start = EPHY_ACTION_BAR_START (user_data);
+  GActionGroup *action_group;
+  GAction *action;
+
+  action_group = gtk_widget_get_action_group (gtk_widget_get_ancestor (GTK_WIDGET (action_bar_start), EPHY_TYPE_WINDOW), "toolbar");
+
+  switch (((GdkEventButton *)event)->button) {
+    case GDK_BUTTON_MIDDLE:
+      action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "new-tab-from-clipboard");
+      g_action_activate (action, NULL);
       break;
     default:
       break;
@@ -450,6 +473,8 @@ ephy_action_bar_start_constructed (GObject *object)
   EphyActionBarStart *action_bar_start = EPHY_ACTION_BAR_START (object);
   EphyEmbedShell *embed_shell;
 
+  G_OBJECT_CLASS (ephy_action_bar_start_parent_class)->constructed (object);
+
   gtk_widget_init_template (GTK_WIDGET (action_bar_start));
 
   /* Back */
@@ -484,6 +509,13 @@ ephy_action_bar_start_constructed (GObject *object)
   }
   g_signal_connect (action_bar_start->homepage_button, "button-release-event",
                     G_CALLBACK (homepage_button_release_event_cb), action_bar_start);
+
+  /* New Tab Button */
+  if (ephy_embed_shell_get_mode (embed_shell) == EPHY_EMBED_SHELL_MODE_APPLICATION)
+    gtk_widget_set_visible (action_bar_start->new_tab_button, FALSE);
+
+  g_signal_connect (action_bar_start->new_tab_button, "button-release-event",
+                    G_CALLBACK (new_tab_button_release_event_cb), action_bar_start);
 }
 
 static void
